==> cscec5b-sync-impl-3.0.0-20201225.123140-25-sources.jar: com/ejianc/business/sync/bean/Imgprog.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

@TableName("WJHN_IMGPROG")//形象进度
public class Imgprog {
    @TableId("PK_IMGPROG")
    private String pkImgprog;//主键 CHAR(20) 20
    @TableField("PK_CORP")
    private String pkCorp;//公司 CHAR(20) 20 是
    @TableField("PK_PROJECT")
    private String pkProject;//项目 CHAR(20) 20 是
    @TableField("PK_CONTRACT")
    private String pkContract;//分包合同 CHAR(20) 20 是
    @TableField("BISSETTLE")
    private String bisSettle;//是否结算 CHAR(1) 1 是
    @TableField("CSRCID")
    private String csrcId;// 来源单据主表主键 CHAR(20) 20 是
    @TableField("CSRCBID")
    private String csrcbId;// 来源单据表体主键 CHAR(20) 20 是
    @TableField("VBILLCODE")
    private String vBillCode;//单据编号2 VARCHAR(100) 100 是
    @TableField("PERIOD")
    private String period;//期间 VARCHAR(100) 100 是
    @TableField("REPORTPERSON")
    private String reportPerson;//上报人 VARCHAR(20) 20 是  ~
    @TableField("NCONFIRMMNY")
    private BigDecimal nConfirmMny;//确认金额 DECIMAL(20,8) 20 是

    private String ts;

    // 子表
    @TableField(exist = false)
    @SubEntity(serviceName="imgprogbService",pidName = "pkImgprog")
    private List<Imgprogb> detailList = new ArrayList<>();

    public List<Imgprogb> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<Imgprogb> detailList) {
        this.detailList = detailList;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }
    public String getPkCorp() {
        return pkCorp;
    }

    public void setPkCorp(String pkCorp) {
        this.pkCorp = pkCorp;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getBisSettle() {
        return bisSettle;
    }

    public void setBisSettle(String bisSettle) {
        this.bisSettle = bisSettle;
    }

    public String getCsrcId() {
        return csrcId;
    }

    public void setCsrcId(String csrcId) {
        this.csrcId = csrcId;
    }

    public String getCsrcbId() {
        return csrcbId;
    }

    public void setCsrcbId(String csrcbId) {
        this.csrcbId = csrcbId;
    }

    public String getvBillCode() {
        return vBillCode;
    }

    public void setvBillCode(String vBillCode) {
        this.vBillCode = vBillCode;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public String getReportPerson() {
        return reportPerson;
    }

    public void setReportPerson(String reportPerson) {
        this.reportPerson = reportPerson;
    }

    public BigDecimal getnConfirmMny() {
        return nConfirmMny;
    }

    public void setnConfirmMny(BigDecimal nConfirmMny) {
        this.nConfirmMny = nConfirmMny;
    }

    public String getPkImgprog() {
        return pkImgprog;
    }

    public void setPkImgprog(String pkImgprog) {
        this.pkImgprog = pkImgprog;
    }

}

==> cscec5b-sync-impl-3.0.1-20230919.074106-50-sources.jar: com/ejianc/business/sync/bean/Imgprog.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

@TableName("WJHN_IMGPROG")//形象进度
public class Imgprog {
    @TableId("PK_IMGPROG")
    private String pkImgprog;//主键 CHAR(20) 20
    @TableField("PK_CORP")
    private String pkCorp;//公司 CHAR(20) 20 是
    @TableField("PK_PROJECT")
    private String pkProject;//项目 CHAR(20) 20 是
    @TableField("PK_CONTRACT")
    private String pkContract;//分包合同 CHAR(20) 20 是
    @TableField("BISSETTLE")
    private String bisSettle;//是否结算 CHAR(1) 1 是
    @TableField("CSRCID")
    private String csrcId;// 来源单据主表主键 CHAR(20) 20 是
    @TableField("CSRCBID")
    private String csrcbId;// 来源单据表体主键 CHAR(20) 20 是
    @TableField("VBILLCODE")
    private String vBillCode;//单据编号2 VARCHAR(100) 100 是
    @TableField("PERIOD")
    private String period;//期间 VARCHAR(100) 100 是
    @TableField("REPORTPERSON")
    private String reportPerson;//上报人 VARCHAR(20) 20 是  ~
    @TableField("NCONFIRMMNY")
    private BigDecimal nConfirmMny;//确认金额 DECIMAL(20,8) 20 是

    private String ts;

    // 子表
    @TableField(exist = false)
    @SubEntity(serviceName="imgprogbService",pidName = "pkImgprog")
    private List<Imgprogb> detailList = new ArrayList<>();

    // 扣款表
    @TableField(exist = false)
    @SubEntity(serviceName="grapCutService",pidName = "pkImgprog")
    private List<GrapCut> cutDetailList = new ArrayList<>();

    public List<Imgprogb> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<Imgprogb> detailList) {
        this.detailList = detailList;
    }

    public List<GrapCut> getCutDetailList() {
        return cutDetailList;
    }

    public void setCutDetailList(List<GrapCut> cutDetailList) {
        this.cutDetailList = cutDetailList;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }
    public String getPkCorp() {
        return pkCorp;
    }

    public void setPkCorp(String pkCorp) {
        this.pkCorp = pkCorp;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getBisSettle() {
        return bisSettle;
    }

    public void setBisSettle(String bisSettle) {
        this.bisSettle = bisSettle;
    }

    public String getCsrcId() {
        return csrcId;
    }

    public void setCsrcId(String csrcId) {
        this.csrcId = csrcId;
    }

    public String getCsrcbId() {
        return csrcbId;
    }

    public void setCsrcbId(String csrcbId) {
        this.csrcbId = csrcbId;
    }

    public String getvBillCode() {
        return vBillCode;
    }

    public void setvBillCode(String vBillCode) {
        this.vBillCode = vBillCode;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public String getReportPerson() {
        return reportPerson;
    }

    public void setReportPerson(String reportPerson) {
        this.reportPerson = reportPerson;
    }

    public BigDecimal getnConfirmMny() {
        return nConfirmMny;
    }

    public void setnConfirmMny(BigDecimal nConfirmMny) {
        this.nConfirmMny = nConfirmMny;
    }

    public String getPkImgprog() {
        return pkImgprog;
    }

    public void setPkImgprog(String pkImgprog) {
        this.pkImgprog = pkImgprog;
    }

}
